# phy-credit, python version of shy-credit

* v0.4.7

* [original shy-credit](https://github.com/Superb-AI-Suite/shy-credit)

* Temporary python version

## Getting started

### Local Build
```
$ pip install .
```

### Local Test
```
$ pipenv install --dev
$ pipenv run pytest
```

### Pip not published yet
